Obtains predicted survivals from a fitted surv.svm object.
Applies the learned Cox calibration to the new raw utility scores.
Usage
# S3 method for class 'surv.svm'
predict(object, newdata, new.times, ...)Value
A numeric matrix of predicted survival probabilities, where rows correspond
to the observations in newdata and columns correspond to the evaluation
times in new.times.
Examples
if (requireNamespace("survivalsvm", quietly = TRUE) &&
requireNamespace("quadprog", quietly = TRUE)) {
data("metabric", package = "SuperSurv")
dat <- metabric[1:25, ]
x_cols <- grep("^x", names(dat))[1:3]
X <- dat[, x_cols, drop = FALSE]
newX <- X[1:5, , drop = FALSE]
times <- seq(50, 150, by = 50)
fit <- surv.svm(
time = dat$duration,
event = dat$event,
X = X,
newdata = newX,
new.times = times
)
pred <- predict(fit$fit, newdata = newX, new.times = times)
dim(pred)
}
#> [1] 5 3