Access variables selected by SuperSurv screeners
Source:R/SuperSurv-methods.R
selected_variables.RdReturns the variables retained by a screening step for one or more fitted event or censoring learners.
Usage
selected_variables(object, ...)
# S3 method for class 'SuperSurv'
selected_variables(object, type = c("event", "censoring"), learner = NULL, ...)